# Paddy ![CI status](https://img.shields.io/badge/build-passing-brightgreen.svg)

Paddy is a Python library for trading.

## Installation

### Requirements
* Linux
* Python 2.7 and up

`$ pip install chance-paddy`

## Usage

```python
from paddy import Trader

trader = Trader(**arguments)
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)
